@@ -528,7 +528,7 @@ class GibbsEnergyPredictor(object):
         # of all the values in cov_dg. For the uncertainty we take the square
         # root of the sum.
 
-        uncertainty = np.sqrt(np.sum(cov_dg.flat))
+        uncertainty = np.sqrt(sum(cov_dg.flat))
         standard_dg = (standard_dg[0] + standard_dg[1]).plus_minus(uncertainty)
 
         # Here we calculate the transform (since the two reactions are in
